import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { DataBrewClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../DataBrewClient";
import { UpdateRecipeRequest, UpdateRecipeResponse } from "../models/models_0";
/**
 * @public
 */
export { __MetadataBearer, $Command };
/**
 * @public
 *
 * The input for {@link UpdateRecipeCommand}.
 */
export interface UpdateRecipeCommandInput extends UpdateRecipeRequest {
}
/**
 * @public
 *
 * The output of {@link UpdateRecipeCommand}.
 */
export interface UpdateRecipeCommandOutput extends UpdateRecipeResponse, __MetadataBearer {
}
declare const UpdateRecipeCommand_base: {
    new (input: UpdateRecipeCommandInput): import("@smithy/smithy-client").CommandImpl<UpdateRecipeCommandInput, UpdateRecipeCommandOutput, DataBrewClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * @public
 * <p>Modifies the definition of the <code>LATEST_WORKING</code> version of a DataBrew
 *             recipe.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { DataBrewClient, UpdateRecipeCommand } from "@aws-sdk/client-databrew"; // ES Modules import
 * // const { DataBrewClient, UpdateRecipeCommand } = require("@aws-sdk/client-databrew"); // CommonJS import
 * const client = new DataBrewClient(config);
 * const input = { // UpdateRecipeRequest
 *   Description: "STRING_VALUE",
 *   Name: "STRING_VALUE", // required
 *   Steps: [ // RecipeStepList
 *     { // RecipeStep
 *       Action: { // RecipeAction
 *         Operation: "STRING_VALUE", // required
 *         Parameters: { // ParameterMap
 *           "<keys>": "STRING_VALUE",
 *         },
 *       },
 *       ConditionExpressions: [ // ConditionExpressionList
 *         { // ConditionExpression
 *           Condition: "STRING_VALUE", // required
 *           Value: "STRING_VALUE",
 *           TargetColumn: "STRING_VALUE", // required
 *         },
 *       ],
 *     },
 *   ],
 * };
 * const command = new UpdateRecipeCommand(input);
 * const response = await client.send(command);
 * // { // UpdateRecipeResponse
 * //   Name: "STRING_VALUE", // required
 * // };
 *
 * ```
 *
 * @param UpdateRecipeCommandInput - {@link UpdateRecipeCommandInput}
 * @returns {@link UpdateRecipeCommandOutput}
 * @see {@link UpdateRecipeCommandInput} for command's `input` shape.
 * @see {@link UpdateRecipeCommandOutput} for command's `response` shape.
 * @see {@link DataBrewClientResolvedConfig | config} for DataBrewClient's `config` shape.
 *
 * @throws {@link ResourceNotFoundException} (client fault)
 *  <p>One or more resources can't be found.</p>
 *
 * @throws {@link ValidationException} (client fault)
 *  <p>The input parameters for this request failed validation.</p>
 *
 * @throws {@link DataBrewServiceException}
 * <p>Base exception class for all service exceptions from DataBrew service.</p>
 *
 */
export declare class UpdateRecipeCommand extends UpdateRecipeCommand_base {
}
